# FeatureProbe Server Side SDK for Python

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/featureprobe-server)
[![codecov](https://codecov.io/gh/FeatureProbe/server-sdk-python/branch/main/graph/badge.svg)](https://codecov.io/gh/FeatureProbe/server-sdk-python)
[![GitHub Star](https://img.shields.io/github/stars/FeatureProbe/server-sdk-python)](https://github.com/FeatureProbe/server-sdk-python/stargazers)
[![License](https://img.shields.io/github/license/FeatureProbe/server-sdk-python)](https://github.com/FeatureProbe/server-sdk-python/blob/main/LICENSE)


Feature Probe is an open source feature management service. This SDK is used to control features in Python programs.
This SDK is designed primarily for use in multi-user systems such as web servers and applications.


## Basic Terms

Reading the short [Basic Terms](https://github.com/FeatureProbe/FeatureProbe/blob/main/BASIC_TERMS.md) will help to understand the code blow more easily.  [中文](https://github.com/FeatureProbe/FeatureProbe/blob/main/BASIC_TERMS_CN.md)


## How to User This SDK

See [SDK Doc](https://docs.featureprobe.io/sdk/Server-Side%20SDKs/python-sdk) for detail.  [中文](https://docs.featureprobe.io/zh-CN/sdk/Server-Side%20SDKs/python-sdk)

## Contributing

We are working on continue evolving FeatureProbe core, making it flexible and easier to use. 
Development of FeatureProbe happens in the open on GitHub, and we are grateful to the 
community for contributing bugfixes and improvements.

Please read [CONTRIBUTING](https://github.com/FeatureProbe/featureprobe/blob/master/CONTRIBUTING.md) 
for details on our code of conduct, and the process for taking part in improving FeatureProbe.

## License

This project is licensed under the Apache 2.0 License - see the [LICENSE](LICENSE) file for details.
